package com.coherentlogic.fred.client.core.domain;

import static com.coherentlogic.fred.client.core.util.Constants.DATE;
import static com.coherentlogic.fred.client.core.util.Constants.OBSERVATION;
import static com.coherentlogic.fred.client.core.util.Constants.OBSERVATION_DATE;
import static com.coherentlogic.fred.client.core.util.Constants.OBSERVATION_VALUE;
import static com.coherentlogic.fred.client.core.util.Constants.REALTIME_END;
import static com.coherentlogic.fred.client.core.util.Constants.REALTIME_START;
import static com.coherentlogic.fred.client.core.util.Constants.VALUE;

import java.math.BigDecimal;
import java.util.Date;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;

import com.coherentlogic.coherent.data.model.core.domain.DefaultObject;
import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * A class which represents an observation or data value for an economic data
 * series.
 *
 * @see <a href="http://api.stlouisfed.org/docs/fred/series_observations.html">
 * series_observations</a>
 *
 * @author <a href="support@coherentlogic.com">Support</a>
 */
@Entity
@Table(name=OBSERVATION)
@XStreamAlias(OBSERVATION)
public class Observation extends DefaultObject {

    private static final long serialVersionUID = 6486475583511786350L;

    @XStreamAlias(REALTIME_START)
    @XStreamAsAttribute
    private Date realtimeStart = null;

    @XStreamAlias(REALTIME_END)
    @XStreamAsAttribute
    private Date realtimeEnd = null;

    @XStreamAlias(DATE)
    @XStreamAsAttribute
    private Date date = null;

    @XStreamAlias(VALUE)
    @XStreamAsAttribute
    private BigDecimal value = null;

    public Date getRealtimeStart() {
        return clone (realtimeStart);
    }

    public void setRealtimeStart(Date realtimeStart) {
        this.realtimeStart = clone (realtimeStart);
    }

    public Date getRealtimeEnd() {
        return clone (realtimeEnd);
    }

    public void setRealtimeEnd(Date realtimeEnd) {
        this.realtimeEnd = clone (realtimeEnd);
    }

    @Column(name=OBSERVATION_DATE)
    public Date getDate() {
        return clone (date);
    }

    public void setDate(Date date) {
        this.date = clone (date);
    }

    @Column(name=OBSERVATION_VALUE)
    public BigDecimal getValue() {
        return value;
    }

    public void setValue(BigDecimal value) {
        this.value = value;
    }
}
